"""

    iceaddr: Look up information about Icelandic streets, addresses,
             placenames, landmarks, locations and postcodes.

    Copyright (c) 2018-2023 Sveinbjorn Thordarson.

"""

__author__ = "Sveinbjorn Thordarson"
__version__ = "0.5.7"  # Also update setup.py

from .addresses import *  # noqa: F403
from .placenames import *  # noqa: F403
from .postcodes import *  # noqa: F403
